
%undefine _strict_symbol_defs_build

%global with_zts    0%{?__ztsphp:1}
%global pecl_name   yac
%global with_tests  %{!?_without_tests:1}%{?_without_tests:0}
%global ini_name    50-%{pecl_name}.ini

Summary:        Lockless user data cache
Name:           php-pecl-%{pecl_name}
Version:        2.3.1
Release:    2%{?dist}

License:        PHP-3.01
URL:            https://pecl.php.net/package/%{pecl_name}
Source0:        https://pecl.php.net/get/%{pecl_name}-%{version}.tgz

BuildRequires:  make
BuildRequires:  gcc
BuildRequires:  php-devel >= 7.0
BuildRequires:  php-pear
BuildRequires:  php-json
BuildRequires:  php-pecl-msgpack-devel
BuildRequires:  php-pecl-igbinary-devel
BuildRequires:  fastlz-devel

Requires:       php(zend-abi) = %{php_zend_api}
Requires:       php(api) = %{php_core_api}
Requires:       php-json
Requires:       php-igbinary
Requires:       php-msgpack

Provides:       php-%{pecl_name} = %{version}
Provides:       php-%{pecl_name} = %{version}
Provides:       php-pecl(%{pecl_name}) = %{version}
Provides:       php-pecl(%{pecl_name}) = %{version}


%description
Yac (Yet Another Cache) is a shared memory user data cache for PHP.

It can be used to replace APC or local memcached.

Yac is lockless, that means, it is very fast, but there could be a
chance you will get a wrong data(depends on how many key slots are
allocated and how many keys are stored), so you'd better make sure
that your product is not very sensitive to that.


%prep
%setup -qc
mv %{pecl_name}-%{version} NTS

sed -e 's/role="test"/role="src"/' \
    -e '/LICENSE/s/role="doc"/role="src"/' \
    -i package.xml

cd NTS
sed -e '\:name="compressor/fastlz:d' -i ../package.xml
rm -r compressor/fastlz

extver=$(sed -n '/#define PHP_YAC_VERSION/{s/.* "//;s/".*$//;p}' php_yac.h)
if test "x${extver}" != "x%{version}%{?prever}"; then
   : Error: Upstream YAC version is ${extver}, expecting %{version}%{?prever}.
   exit 1
fi
cd ..

cat > %{ini_name} << 'EOF'
; Enable Yet Another Cache extension module
extension = %{pecl_name}.so

;yac.enable=1
;yac.enable_cli=0
;yac.debug=0
;yac.keys_memory_size=4M
;yac.values_memory_size=64M
;yac.compress_threshold=-1
;yac.serializer=php
EOF


%if %{with_zts}
cp -pr NTS ZTS
%endif


%build
peclconf() {
%configure \
    --enable-json \
    --enable-msgpack \
    --enable-igbinary \
    --with-system-fastlz \
    --with-php-config=$1
}

cd NTS
%{_bindir}/phpize
peclconf %{_bindir}/php-config
make %{?_smp_mflags}

%if %{with_zts}
cd ../ZTS
%{_bindir}/zts-phpize
peclconf %{_bindir}/zts-php-config
make %{?_smp_mflags}
%endif


%install
make -C NTS install INSTALL_ROOT=%{buildroot}
install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

install -D -m 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

%if %{with_zts}
make -C ZTS install INSTALL_ROOT=%{buildroot}
install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

for i in $(grep 'role="doc"' package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 NTS/$i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done


%check
OPTS="-n"
[ -f %{php_extdir}/json.so     ] && OPTS="$OPTS -d extension=json.so"
[ -f %{php_extdir}/igbinary.so ] && OPTS="$OPTS -d extension=igbinary.so"
[ -f %{php_extdir}/msgpack.so  ] && OPTS="$OPTS -d extension=msgpack.so"

cd NTS

: Minimal load test for NTS extension
%{_bindir}/php $OPTS  \
    --define extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'

%if %{with_tests}
: Upstream test suite for NTS extension
TEST_PHP_ARGS="$OPTS -d extension=$PWD/modules/%{pecl_name}.so" \
%{__php} -n run-tests.php -q --show-diff
%else
: Upstream test suite disabled
%endif

%if %{with_zts}
cd ../ZTS

: Minimal load test for ZTS extension
%{__ztsphp} $OPTS \
    --define extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'

%if %{with_tests}
: Upstream test suite for ZTS extension
TEST_PHP_ARGS="$OPTS -d extension=$PWD/modules/%{pecl_name}.so" \
%{__ztsphp} -n run-tests.php -q --show-diff
%else
: Upstream test suite disabled
%endif
%endif


%files
%license NTS/LICENSE
%doc %{pecl_docdir}/%{pecl_name}
%{pecl_xmldir}/%{name}.xml

%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%{php_ztsextdir}/%{pecl_name}.so
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%endif


%changelog
* Wed Jun 11 2025 bbrucezhang <bbrucezhang@tencent.com> - 2.3.1-2
- Rebuilt for loongarch64

* Fri Apr 12 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.3.1-1
- initial build
